/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.facebook.presto.execution;

import com.facebook.presto.Session;
import com.facebook.presto.metadata.Metadata;
import com.facebook.presto.metadata.QualifiedTableName;
import com.facebook.presto.metadata.ViewDefinition;
import com.facebook.presto.sql.analyzer.SemanticException;
import com.facebook.presto.sql.tree.DropView;

import java.util.Optional;

import static com.facebook.presto.metadata.MetadataUtil.createQualifiedTableName;
import static com.facebook.presto.sql.analyzer.SemanticErrorCode.MISSING_TABLE;

public class DropViewTask
        implements DataDefinitionTask<DropView>
{
    @Override
    public void execute(DropView statement, Session session, Metadata metadata, QueryStateMachine stateMachine)
    {
        QualifiedTableName name = createQualifiedTableName(session, statement.getName());

        Optional<ViewDefinition> view = metadata.getView(session, name);
        if (!view.isPresent()) {
            throw new SemanticException(MISSING_TABLE, statement, "View '%s' does not exist", name);
        }

        metadata.dropView(session, name);
    }
}
