/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.facebook.presto.execution;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import com.google.common.base.Objects;

import java.util.List;

import static com.facebook.presto.execution.QueryId.validateId;
import static com.google.common.base.Preconditions.checkNotNull;

public class StageId
{
    @JsonCreator
    public static StageId valueOf(String stageId)
    {
        List<String> ids = QueryId.parseDottedId(stageId, 2, "stageId");
        return new StageId(new QueryId(ids.get(0)), ids.get(1));
    }

    private final QueryId queryId;
    private final String id;

    public StageId(QueryId queryId, String id)
    {
        this.queryId = checkNotNull(queryId, "queryId is null");
        this.id = validateId(id);
    }

    public StageId(String queryId, String id)
    {
        this.queryId = new QueryId(queryId);
        this.id = validateId(id);
    }

    public QueryId getQueryId()
    {
        return queryId;
    }

    public String getId()
    {
        return id;
    }

    @Override
    @JsonValue
    public String toString()
    {
        return queryId + "." + id;
    }

    @Override
    public int hashCode()
    {
        return Objects.hashCode(id, queryId);
    }

    @Override
    public boolean equals(Object obj)
    {
        if (this == obj) {
            return true;
        }
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        final StageId other = (StageId) obj;
        return Objects.equal(this.id, other.id) &&
                Objects.equal(this.queryId, other.queryId);
    }
}
